#
# spec file for package libXdmcp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXdmcp
%define lname	libXdmcp6
Version:        1.1.5
Release:        1.4
Summary:        X Display Manager Control Protocol library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXdmcp
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXdmcp/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf >= 2.60
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(xorg-macros) >= 1.12
BuildRequires:  pkgconfig(xproto)

%description
The X Display Manager Control Protocol (XDMCP) provides a uniform
mechanism for an autonomous display to request login service from a
remote host. By autonomous, we mean the display consists of hardware
and processes that are independent of any particular host where login
service is desired. An X terminal (screen, keyboard, mouse,
processor, network interface) is a prime example of an autonomous
display.

%package -n %lname
Summary:        X Display Manager Control Protocol library
# O/P added for 12.2
Group:          System/Libraries
Provides:       xorg-x11-libXdmcp = 7.6_%version-%release
Obsoletes:      xorg-x11-libXdmcp < 7.6_%version-%release

%description -n %lname
The X Display Manager Control Protocol (XDMCP) provides a uniform
mechanism for an autonomous display to request login service from a
remote host. By autonomous, we mean the display consists of hardware
and processes that are independent of any particular host where login
service is desired. An X terminal (screen, keyboard, mouse,
processor, network interface) is a prime example of an autonomous
display.

%package devel
Summary:        Development files for the XDM Control Protocol library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
# O/P added for 12.2
Provides:       xorg-x11-libXdmcp-devel = 7.6_%version-%release
Obsoletes:      xorg-x11-libXdmcp-devel < 7.6_%version-%release

%description devel
The X Display Manager Control Protocol (XDMCP) provides a uniform
mechanism for an autonomous display to request login service from a
remote host. By autonomous, we mean the display consists of hardware
and processes that are independent of any particular host where login
service is desired. An X terminal (screen, keyboard, mouse,
processor, network interface) is a prime example of an autonomous
display.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
autoreconf -fi
%configure --docdir=%_docdir/%name --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXdmcp.so.6*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXdmcp.so
%_libdir/pkgconfig/xdmcp.pc
%_docdir/%name

%changelog
* Sun Mar  3 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.5
  * Remove "All rights reserved" from Oracle copyright notices
  * configure: Use LT_INIT from libtool 2 instead of deprecated
    AC_PROG_LIBTOOL
  * Xdmcp.h: add access attributes to function prototypes
  * Clear -Wunused-macros warnings when arc4random_buf() is available
  * XdmcpWriteHeader: drop unnecessary cast of free() argument
  * XdmcpWriteHeader: use calloc instead of malloc to alloc buffer
  * gitlab CI: add xz-utils to container for "make distcheck"
* Sun Nov 20 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.4
  * Update configure.ac bug URL for gitlab migration
  * gitlab CI: add a basic build test
  * Fix build on Solaris 11.3.0 - 11.3.8
  * Fix spelling/wording issues
  * gitlab CI: enable doc builds in basic build test
  * Use memcpy() instead of memmove() when buffers are known not to overlap
  * arc4random_buf: Only declare ret if HAVE_GETENTROPY is defined
  * XdmcpDisposeARRAYofARRAY8: Reduce scope of i
  * Only link with libbsd if needed for arc4random_buf()
  * Switch from libbsd to libbsd-overlay
* Thu Mar 21 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.3
  * This release provides a fix for CVE-2017-2625 for platforms which don't have
    arc4random_buf() in their default libraries but do have getentropy(), such
    as Linux platforms with a kernel version of 3.17 or newer and a glibc version
    of 2.25 or newer.   (libXdmcp 1.1.2 already ensured that arc4random_buf()
    is used on platforms that have it to provide sufficient entropy in XDMCP
    key generation, but left other platforms with the weaker methods.  Linux
    platforms could also have linked against libbsd to use arc4random_buf()
    with libXdmcp 1.1.2 for stronger keys.)
- supersedes U_Fix-compilation-error-when-arc4random_buf-is-not-ava.patch,
  U_Use-getentropy-if-arc4random_buf-is-not-available.patch
* Sun Jun 11 2017 sndirsch@suse.com
- U_Use-getentropy-if-arc4random_buf-is-not-available.patch
  * Use getentropy() if arc4random_buf() is not available
    (bsc#1025046, CVE-2017-2625)
- U_Fix-compilation-error-when-arc4random_buf-is-not-ava.patch
  * Fix compilation error when arc4random_buf is not available
* Mon Mar 23 2015 sndirsch@suse.com
- added baselibs.conf as source to specfile
* Sun Mar 22 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.1.2:
  This release has hardened handling of invalid arguments &
  allocation failures, adds support for using arc4random in key
  generation, and adds some unit tests to help developers prevent
  regressions in the future.
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.1.1:
  + Improvements to documentation
  + Build configuration improvements
* Sat Feb 11 2012 jengelh@medozas.de
- Provide package descriptions and update homepage URL
* Sat Feb 11 2012 jengelh@medozas.de
- Rename xorg-x11-libXdmcp to libXdmcp and utilize shlib policy
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6
* Wed Dec  1 2010 sndirsch@novell.com
- revert 'export only public API symbols'
  it breaks at least build of xdm (package xorg-x11)
* Tue Nov 30 2010 cristian.rodriguez@opensuse.org
- export only public API symbols
- disable silent rules, defeat the purpose of post build checks
* Sat Oct 30 2010 sndirsch@novell.com
- libXdmcp 1.1.0
  * This release features a major refactoring and cleanup of the
    code base, and conversion of the XDMCP specification from
    troff to DocBook/XML, along with the usual recent set of build
    configuration improvements and janitorial cleanups.
* Sun Apr  4 2010 sndirsch@suse.de
- libXdmcp 1.0.3
- bumped version number to 7.5
* Tue Dec 15 2009 sndirsch@suse.de
- add baselibs.conf as a source
* Sat May  2 2009 eich@suse.de
- revert static library and .la file removal
  for SUSE versions <= 11.1.
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Dec 26 2007 crrodriguez@suse.de
- fix library-without-ldconfig-postun error
- PreReq coreutils
- libXdmcp.la has dependency_libs empty, removed.
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Thu Oct 26 2006 sndirsch@suse.de
- set version to 7.2 in specfile
* Sat Aug 12 2006 sndirsch@suse.de
- updated to minor cleanup release 1.0.2
  * added hooks for checking code with lint & sparse, and cleaned
    up a couple of warnings from them.
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
- remove existing /usr/include/X11 symlink in %%pre
* Thu Jun 22 2006 sndirsch@suse.de
- created package
